from ..common.enums import DetailType
from .weakness import WEAKNESS_STARTING_DETAIL_PATTERN_2, WEAKNESS_PATTERNS
from .configuration import CONFIG_STARTING_DETAIL_PATTERN, CONFIGURATION_PATTERNS
from .component import COMPONENT_STARTING_DETAIL_PATTERN, COMPONENT_PATTERNS


STARTING_DETAILS_MAPPING = {
    DetailType.COMPONENT: COMPONENT_STARTING_DETAIL_PATTERN,
    DetailType.CONFIGURATION: CONFIG_STARTING_DETAIL_PATTERN,
    DetailType.WEAKNESS: WEAKNESS_STARTING_DETAIL_PATTERN_2
}
