




# component configuration weakness vector impact
# DETAILS_5_2 = (COMPONENT_PATTERN + CONFIGURATION_BEFORE_STOP_WORDS +
#               CONFIGURATION_PATTERN + WEAKNESS_BEFORE_STOP_WORDS + WEAKNESS_PATTERN +
#               VECTOR_BEFORE_STOP_WORDS + VECTOR_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + r'\.')

